.. image:: https://travis-ci.org/asphalt-framework/asphalt-py4j.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-py4j
  :alt: Build Status
.. image:: https://coveralls.io/repos/asphalt-framework/asphalt-py4j/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/asphalt-framework/asphalt-py4j?branch=master
  :alt: Code Coverage
.. image:: https://codeclimate.com/github/asphalt-framework/asphalt-py4j/badges/gpa.svg
  :target: https://codeclimate.com/github/asphalt-framework/asphalt-py4j
  :alt: Code Climate

This is a component for the Asphalt framework that provides Py4J_ integration.

Py4J allows you to call Java code from Python by either spawning a slave JVM
(`Java Virtual Machine`_) in a subprocess or by connecting to an existing JVM.


Project links
-------------

* `Documentation`_
* `Help and support`_
* `Source code`_
* `Issue tracker`_


.. _Py4J: https://www.py4j.org/
.. _Java Virtual Machine: https://en.wikipedia.org/wiki/Java_virtual_machine
.. _Documentation: http://asphalt-py4j.readthedocs.org/en/latest/
.. _Help and support: https://github.com/asphalt-framework/asphalt/wiki/Help-and-support
.. _Source code: https://github.com/asphalt-framework/asphalt-py4j
.. _Issue tracker: https://github.com/asphalt-framework/asphalt-py4j/issues
